@@ -123,7 +123,9 @@ class TestConvertMethod:
                     )
 
                     assert (output_path.with_suffix(".chunks.json")).exists()
-                    saved_chunks = json.loads((output_path.with_suffix(".chunks.json")).read_text())
+                    saved_chunks = json.loads(
+                        (output_path.with_suffix(".chunks.json")).read_text()
+                    )
                     assert saved_chunks == {"some_content": True}
 
     def test_convert_sync_with_processing_options(self, temp_dir):
@@ -133,9 +135,7 @@ class TestConvertMethod:
         pdf_file.write_bytes(b"%PDF-1.4\n%Test PDF content\n%%EOF\n")
 
         # Create processing options
-        options = ConvertOptions(
-            force_ocr=True, output_format="html", use_llm=True, max_pages=5
-        )
+        options = ConvertOptions(output_format="html", max_pages=5)
 
         # Mock API responses
         mock_initial_response = {
@@ -504,13 +504,13 @@ class TestClientErrorHandling:
             with patch.object(
                 client, "_make_request", new_callable=AsyncMock
             ) as mock_request:
-                # Setup mock to raise API error
+                # Setup mock to raise API error (use 400 since 429 is retried)
                 mock_request.side_effect = DatalabAPIError(
-                    "API rate limit exceeded", status_code=429
+                    "Bad request", status_code=400
                 )
 
                 # Test that error is propagated
-                with pytest.raises(DatalabAPIError, match="API rate limit exceeded"):
+                with pytest.raises(DatalabAPIError, match="Bad request"):
                     await client.ocr(pdf_file)
 
     def test_convert_unsuccessful_response(self, temp_dir):
